@@ -1,6 +1,4 @@
-import numpy as np
 import pytesseract
-from PIL import Image
 
 
 def extract_text(image, top_left=None, bottom_right=None):
@@ -15,8 +13,6 @@ def extract_text(image, top_left=None, bottom_right=None):
     Returns:
         str: Extracted text.
     """
-    if isinstance(image, Image.Image):
-        image = np.array(image)
     if top_left is not None and bottom_right is not None:
         x1, y1 = top_left
         x2, y2 = bottom_right
