@@ -9,10 +9,16 @@ class Center(Shell):
         self.execute("xdotool click --clearmodifiers 2")
 
 
+class Right(Shell):
+    def click(self):
+        self.execute("xdotool click --clearmodifiers 3")
+
+
 class Mouse(Shell):
 
     def __init__(self):
         self.center = Center()
+        self.right = Right()
 
     @property
     def current_position(self):
@@ -23,9 +29,12 @@ class Mouse(Shell):
     def _move(self, x, y):
         self.execute(f"xdotool mousemove --clearmodifiers --sync {x} {y}")
 
-    def move(self, x, y):
+    def move(self, x, y, fast=False):
         current = self.current_position
-        wind_mouse(*current.values(), x, y, move_mouse=self._move)
+        if fast:
+            self._move(x, y)
+        else:
+            wind_mouse(*current.values(), x, y, move_mouse=self._move)
 
     def click(self):
         self.execute("xdotool click --clearmodifiers 1")
