@@ -1,8 +1,5 @@
 import subprocess
-
-
-class ExecuteException(Exception):
-    pass
+from simulant.shared.exceptions import ExecuteException
 
 
 class Shell:
